@@ -110,7 +110,6 @@ class PaddedTensorDataset(Dataset):
 
 class GeoTimeClassify:
     def __init__(self, number_of_samples):
-        self.cwd = os.getcwd()
         self.model = LSTMClassifier(vocab_size=89, embedding_dim=128, hidden_dim=32, output_size=58)
         self.model.load_state_dict(torch.load(pkg_resources.resource_stream(__name__, 'models/LSTM_RNN_Geotime_Classify_v_0.07_dict.pth')))
         self.model.eval()
@@ -538,25 +537,6 @@ class GeoTimeClassify:
                 ],
         }
 
-    # def load_csvs(self):
-    #     try:
-    #         stream = pkg_resources.resource_stream(__name__, 'datasets/country.csv')
-    #         self.country_lookup= pd.read_csv(stream, encoding='latin-1')
-    #         # self.country_lookup = pd.read_csv(pkg_resources.resource_stream(__name__, 'datasets/country.csv'), encoding='latin-1')
-    #         print('one')
-    #         stream = pkg_resources.resource_stream(__name__, 'datasets/city.csv')
-    #         self.city_lookup = pd.read_csv(stream, encoding='latin-1')
-    #         stream = pkg_resources.resource_stream(__name__, 'datasets/continent_code.csv')
-    #         self.cont_lookup = pd.read_csv(stream, encoding='latin-1')
-    #         stream = pkg_resources.resource_stream(__name__, 'datasets/country_lookup.csv')
-    #         self.country_lookup2 = pd.read_csv(stream, encoding='latin-1')
-    #         stream = pkg_resources.resource_stream(__name__, 'datasets/country_cc_c_number.csv')
-    #         self.c_lookup = pd.read_csv(stream, encoding='latin-1')
-    #         stream = pkg_resources.resource_stream(__name__, 'datasets/NA_states_provinces.csv')
-    #         self.state_lookup = pd.read_csv(stream, encoding='latin-1')
-    #     except Exception as e:
-    #         print(e)
-    #     return 'Success'
     def return_data(self):
         return self.cont_lookup
 
